# DARTFlo Viscous-Inviscid Interaction.
The folder dartflo/dart/viscous/ is dedicated to the viscous inviscid interaction implemented in DARTflo. This section extends DARTflo capabilities to two dimensional steady high Reynolds number transitional viscous flows.
The solver makes use of the integral boundary layer equations (IBL) and the e^N method to correct the inviscid flow solution computed by DARTflo. The solver is divded into two parts. One that solves the steady state IBL and one that deals with the time-dependent IBL solved through a time marching procedure. The communication between the solvers is always done through steady-state solutions. The interaction is able to deal with midly separated flows for which the boundary layer assumptions still hold. 
The two flow domains are coupled through a quasi-simulataneous interaction law that prevents Goldstein singularity. 

![](/dox/title.png)

## Main features
* 2D viscous flow.
* Free/forced laminar to turbulent transition.
* Solver models
  - Steady state equations solution. 
  - Time-dependant equations solution through a pseudo-time marching procedure.

## Solver operation map
The viscous inviscid interaction can be launched from /dart/tests/bli_xxx.py. The class in Master/Coupler.py is first called with the required arguments and manages the two solvers to work togheter. The steady-state equations solver is called from /Solvers/Steady/StdSolver.py. The time-dependent equations solver is called from /Drivers/VDriver.py which initializes the different components of the code and starts the viscous flow computation using an implicit Euler pseudo-time marching procedure. 

## References
Crovato Adrien, [Steady Transonic Aerodynamic and Aeroelastic Modeling for Preliminary Aircraft Design](http://hdl.handle.net/2268/251906), PhD thesis, University of Liège, 2020.

Crovato Adrien, [DARTFlo - Discrete Adjoint for Rapid Transonic Flows](http://hdl.handle.net/2268/264284), Technical note, University of Liège, 2021.

Crovato A., Boman R., et al., [A Full Potential Static Aeroelastic Solver for Preliminary Aircraft Design](http://hdl.handle.net/2268/237955), 18th International Forum on Aeroelasticity and Structural Dynamics, IFASD 2019.

Bilocq Amaury, [Implementation of a viscous-inviscid interaction scheme in a finite element full potential solver](http://hdl.handle.net/2268/252195), Master thesis, University of Liège, 2020.
